==> 4.4.3.tar.gz: terraform-provider-decort/samples/cloudapi/data_rg_list/main.tf <==
/*
Пример использования
Получение информации о списке всех ресурсных группах к которым есть доступ
*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером

/* terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
} */

provider "decort" {
  authenticator = "oauth2"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_rg_list" "rg_list" {
  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - число
  #by_id = 100

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка ресурсных групп
  #опциональный параметр 
  #тип - число
  #account_id = 11111

  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "test"

  #фильтр по времени создания (после указанного времени)
  #опциональный параметр
  #тип - число
  #created_after = "123"

  #фильтр по времени создания (перед указанным временем)
  #опциональный параметр
  #тип - число
  #created_before = "123"

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по lock status
  #опциональный параметр
  #тип - строка
  #lock_status = "UNLOCKED"

  #отображать удаленные ресурсные группы или нет
  #необязательный параметр
  #тип - булевый
  #includedeleted = false
  
  #номер страницы
  #необязательный параметр
  #тип - число
  #page = 1
  
  #размер страницы
  #необязательный параметр
  #тип - число
  #size = 2
}

output "output" {
  value = data.decort_rg_list.rg_list
}

==> 4.5.0.tar.gz: terraform-provider-decort/samples/cloudapi/data_rg_list/main.tf <==
/*
Пример использования
Получение информации о списке всех ресурсных группах к которым есть доступ
*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером

/* terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
} */

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_rg_list" "rg_list" {
  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - число
  #by_id = 100

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка ресурсных групп
  #опциональный параметр 
  #тип - число
  #account_id = 11111

  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "test"

  #фильтр по времени создания (после указанного времени)
  #опциональный параметр
  #тип - число
  #created_after = "123"

  #фильтр по времени создания (перед указанным временем)
  #опциональный параметр
  #тип - число
  #created_before = "123"

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по lock status
  #опциональный параметр
  #тип - строка
  #lock_status = "UNLOCKED"

  #отображать удаленные ресурсные группы или нет
  #необязательный параметр
  #тип - булевый
  #includedeleted = false
  
  #номер страницы
  #необязательный параметр
  #тип - число
  #page = 1
  
  #размер страницы
  #необязательный параметр
  #тип - число
  #size = 2
}

output "output" {
  value = data.decort_rg_list.rg_list
}
